@@ -17,6 +17,25 @@ if [ ! -f terminix ]; then
     exit 1
 fi
 
+# Check availability of required commands
+COMMANDS="install glib-compile-schemas glib-compile-resources msgfmt desktop-file-validate xdg-desktop-menu gtk-update-icon-cache"
+PACKAGES="coreutils glib2 glib2 gettext desktop-file-utils xdg-utils gtk-update-icon-cache"
+i=0
+for COMMAND in $COMMANDS; do
+    type $COMMAND >/dev/null 2>&1 || {
+        j=0
+        for PACKAGE in $PACKAGES; do
+            if [ $i = $j ]; then
+                break
+            fi
+            j=$(( $j + 1 ))
+        done
+        echo "Your system is missing command $COMMAND, please install $PACKAGE"
+        exit 1
+    }
+    i=$(( $i + 1 ))
+done
+
 echo "Installing to prefix ${PREFIX}"
 
 # Copy and compile schema
@@ -86,9 +105,20 @@ install -d ${PREFIX}/share/dbus-1/services
 install -m 644 data/dbus/com.gexperts.Terminix.service ${PREFIX}/share/dbus-1/services/
 
 # Copy man page
+echo "Installing man pages"
 install -d ${PREFIX}/share/man/man1
 install -m 644 data/man/terminix ${PREFIX}/share/man/man1/terminix.1
-gzip /usr/share/man/man1/terminix.1
+gzip -f ${PREFIX}/share/man/man1/terminix.1
+
+if type po4a-translate >/dev/null 2>&1; then
+    for f in data/man/po/*.man.po
+    do
+        LOCALE=$(basename "$f" .man.po)
+        install -d ${PREFIX}/share/man/${LOCALE}/man1
+        po4a-translate -f man -m data/man/terminix -p data/man/po/${LOCALE}.man.po -l ${PREFIX}/share/man/${LOCALE}/man1/terminix.1
+        gzip -f ${PREFIX}/share/man/${LOCALE}/man1/terminix.1
+    done
+fi
 
 # Copy Icons
 cd data/icons/hicolor
